diff NPC.h @ 261:c3bfe1eb3de7

Слияние
author Ritor1
date Mon, 18 Feb 2013 10:30:14 +0600
parents 37dcbe8f3cca
children e22e2357c8b3
line wrap: on
line diff
--- a/NPC.h	Mon Feb 18 10:29:47 2013 +0600
+++ b/NPC.h	Mon Feb 18 10:30:14 2013 +0600
@@ -17,9 +17,11 @@
 #pragma pack(push, 1)
 struct NPCData
 {
+  inline bool Hired() {return uFlags & 0x80;}
+
   char *pName;
   unsigned int uPortraitID;
-  unsigned int uFlags;         // & 0x80    no greeting on dialogue start
+  unsigned int uFlags;         // & 0x80    no greeting on dialogue start; looks like hired
   int fame;
   int rep;
   int house;